#ifndef PDFPAGEITEM_H
#define PDFPAGEITEM_H

#include <QQuickItem>

class VerticalView;
class SGTileItem;
class AbstractRenderTask;
class PdfRenderTask;
class PdfDocument;
class PageDecoration;
class PageOverlay;

class PdfPageItem : public QQuickItem
{
    Q_OBJECT

public:
    PdfPageItem(VerticalView *view, QSharedPointer<PdfDocument> d);
    ~PdfPageItem();

    int index() const { return m_index; }
    void setIndex(int i) { m_index = i; }

protected:
    virtual void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry);

private Q_SLOTS:
    void updateVisibleRect();
    void updateTileData(AbstractRenderTask* task, QImage img);
    void addPageDecoration();
    void addPageOverlay();

private:
    int m_index;

    QMap<int, SGTileItem*> m_tiles;
    VerticalView* m_view;
    QSharedPointer<PdfDocument> m_document;
    PageDecoration* m_decoration;
    PageOverlay* m_overlay;

private:
    void generateTiles(int x1, int y1, int x2, int y2, int tilesPerWidth, int tilesPerHeight);
    void createTile(int index, const QRect& rect);
    void clearView();

    PdfRenderTask *createTask(const QRect &rect, int id) const;
};
#endif // PDFPAGEITEM_H
